Page MenuHomeFreeBSD

D60109.diff
No OneTemporary

D60109.diff

diff --git a/sys/net/if_ovpn.c b/sys/net/if_ovpn.c
--- a/sys/net/if_ovpn.c
+++ b/sys/net/if_ovpn.c
@@ -1757,8 +1757,9 @@
OVPN_PEER_COUNTER_ADD(peer, pkt_in, 1);
OVPN_PEER_COUNTER_ADD(peer, bytes_in, m->m_pkthdr.len);
/* Receive the packet on our interface. */
m->m_pkthdr.rcvif = sc->ifp;
+ M_SETFIB(m, sc->ifp->if_fib);
/* Clear checksum flags in case the real hardware set them. */
m->m_pkthdr.csum_flags = 0;
@@ -1757,8 +1757,9 @@
OVPN_PEER_COUNTER_ADD(peer, pkt_in, 1);
OVPN_PEER_COUNTER_ADD(peer, bytes_in, m->m_pkthdr.len);
- /* Receive the packet on our interface. */
+ /* Receive the packet on our interface and FIB. */
m->m_pkthdr.rcvif = sc->ifp;

File Metadata

Mime Type
text/plain
Expires
Wed, Sep 30, 6:20 AM (13 h, 49 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
39901787
Default Alt Text
D60109.diff (482 B)

Event Timeline